@@ -10,7 +10,7 @@ from iker.common.utils.dbutils import make_scheme
 from iker.common.utils.dtutils import dt_parse_iso
 from iker.common.utils.jsonutils import JsonType
 from iker.common.utils.randutils import randomizer
-from sqlmodel import Field
+from sqlmodel import Field, SQLModel
 
 from plexus.common.utils.ormutils import (
     db_activate_snapshot_model,
@@ -46,42 +46,34 @@ fixture_postgresql_test = pytest_postgresql.factories.postgresql("fixture_postgr
 DummyBaseModel = make_base_model()
 
 
-class DummySerialModel(DummyBaseModel, make_serial_model_mixin(), table=True):
+def make_dummy_model():
+    class Model(SQLModel):
+        dummy_str: str = Field(sa_column=sa.Column(sa_pg.VARCHAR(256)), default="")
+        dummy_int: int = Field(sa_column=sa.Column(sa_pg.BIGINT), default=0)
+        dummy_float: float = Field(sa_column=sa.Column(sa_pg.DOUBLE_PRECISION), default=0.0)
+        dummy_bool: bool = Field(sa_column=sa.Column(sa_pg.BOOLEAN), default=False)
+        dummy_array: list[str] = Field(sa_column=sa.Column(sa_pg.ARRAY(sa_pg.VARCHAR(64))))
+        dummy_json: JsonType = Field(sa_column=sa.Column(sa_pg.JSONB))
+
+    return Model
+
+
+DummyModel = make_dummy_model()
+
+
+class DummySerialModel(DummyBaseModel, make_dummy_model(), make_serial_model_mixin(), table=True):
     __tablename__ = "dummy_serial_model"
 
-    dummy_str: str = Field(sa_column=sa.Column(sa_pg.VARCHAR(256)), default="")
-    dummy_int: int = Field(sa_column=sa.Column(sa_pg.BIGINT), default=0)
-    dummy_float: float = Field(sa_column=sa.Column(sa_pg.DOUBLE_PRECISION), default=0.0)
-    dummy_bool: bool = Field(sa_column=sa.Column(sa_pg.BOOLEAN), default=False)
-    dummy_array: list[str] = Field(sa_column=sa.Column(sa_pg.ARRAY(sa_pg.VARCHAR(64))))
-    dummy_json: JsonType = Field(sa_column=sa.Column(sa_pg.JSONB))
 
-
-class DummyRecordModel(DummyBaseModel, make_record_model_mixin(), table=True):
+class DummyRecordModel(DummyBaseModel, make_dummy_model(), make_record_model_mixin(), table=True):
     __tablename__ = "dummy_record_model"
-
-    dummy_str: str = Field(sa_column=sa.Column(sa_pg.VARCHAR(256)), default="")
-    dummy_int: int = Field(sa_column=sa.Column(sa_pg.BIGINT), default=0)
-    dummy_float: float = Field(sa_column=sa.Column(sa_pg.DOUBLE_PRECISION), default=0.0)
-    dummy_bool: bool = Field(sa_column=sa.Column(sa_pg.BOOLEAN), default=False)
-    dummy_array: list[str] = Field(sa_column=sa.Column(sa_pg.ARRAY(sa_pg.VARCHAR(64))))
-    dummy_json: JsonType = Field(sa_column=sa.Column(sa_pg.JSONB))
-
     __table_args__ = (
         record_model_mixin.make_index_created_at("ix_dummy_record_model_created_at"),
     )
 
 
-class DummySnapshotModel(DummyBaseModel, make_snapshot_model_mixin(), table=True):
+class DummySnapshotModel(DummyBaseModel, make_dummy_model(), make_snapshot_model_mixin(), table=True):
     __tablename__ = "dummy_snapshot_model"
-
-    dummy_str: str = Field(sa_column=sa.Column(sa_pg.VARCHAR(256)), default="")
-    dummy_int: int = Field(sa_column=sa.Column(sa_pg.BIGINT), default=0)
-    dummy_float: float = Field(sa_column=sa.Column(sa_pg.DOUBLE_PRECISION), default=0.0)
-    dummy_bool: bool = Field(sa_column=sa.Column(sa_pg.BOOLEAN), default=False)
-    dummy_array: list[str] = Field(sa_column=sa.Column(sa_pg.ARRAY(sa_pg.VARCHAR(64))))
-    dummy_json: JsonType = Field(sa_column=sa.Column(sa_pg.JSONB))
-
     __table_args__ = (
         snapshot_model_mixin.make_index_created_at_expired_at("ix_dummy_snapshot_model_created_at_expired_at"),
         snapshot_model_mixin.make_active_unique_index_record_sid("ix_au_dummy_snapshot_model_record_sid"),
@@ -107,8 +99,8 @@ def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
 
     rng = randomizer()
 
-    def random_record() -> DummySerialModel:
-        return DummySerialModel(
+    def random_record() -> DummyModel:
+        return DummyModel(
             dummy_int=rng.next_int(0, 1000),
             dummy_str=rng.random_alphanumeric(rng.next_int(10, 20)),
             dummy_float=rng.next_float(0.0, 100.0),
@@ -218,8 +210,8 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
 
     rng = randomizer()
 
-    def random_record() -> DummyRecordModel:
-        return DummyRecordModel(
+    def random_record() -> DummyModel:
+        return DummyModel(
             dummy_int=rng.next_int(0, 1000),
             dummy_str=rng.random_alphanumeric(rng.next_int(10, 20)),
             dummy_float=rng.next_float(0.0, 100.0),
@@ -349,8 +341,8 @@ def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql
 
     rng = randomizer()
 
-    def random_record() -> DummySnapshotModel:
-        return DummySnapshotModel(
+    def random_record() -> DummyModel:
+        return DummyModel(
             dummy_int=rng.next_int(0, 1000),
             dummy_str=rng.random_alphanumeric(rng.next_int(10, 20)),
             dummy_float=rng.next_float(0.0, 100.0),
