@@ -5,6 +5,7 @@ import pyparsing as pp
 from iker.common.utils.dtutils import dt_parse_iso
 
 from plexus.common.utils.strutils import BagName, UserName, VehicleName
+from plexus.common.utils.strutils import colon_tag_parser, colon_tag_pattern, slash_tag_parser, slash_tag_pattern
 from plexus.common.utils.strutils import dot_case_parser, dot_case_pattern
 from plexus.common.utils.strutils import hex_string_parser, hex_string_pattern
 from plexus.common.utils.strutils import kebab_case_parser, kebab_case_pattern
@@ -13,7 +14,6 @@ from plexus.common.utils.strutils import semver_parser, semver_pattern
 from plexus.common.utils.strutils import snake_case_parser, snake_case_pattern
 from plexus.common.utils.strutils import strict_abspath_parser, strict_abspath_pattern
 from plexus.common.utils.strutils import strict_relpath_parser, strict_relpath_pattern
-from plexus.common.utils.strutils import tag_parser, tag_pattern
 from plexus.common.utils.strutils import topic_parser, topic_pattern
 from plexus.common.utils.strutils import vin_code_parser, vin_code_pattern
 
@@ -415,36 +415,67 @@ class StrUtilsTest(unittest.TestCase):
         with self.assertRaises(pp.ParseException):
             semver_parser.parse_string(data, parse_all=True)
 
-    data_tag_pattern = [
+    data_colon_tag_pattern = [
         ("dummy",),
-        ("dummy::dummy",),
-        ("dummy::dummy::dummy",),
-        ("dummy_12345::dummy_12345::dummy_12345",),
+        ("dummy:dummy",),
+        ("dummy:dummy:dummy",),
+        ("dummy_12345:dummy_12345:dummy_12345",),
     ]
 
-    @ddt.idata(data_tag_pattern)
+    @ddt.idata(data_colon_tag_pattern)
     @ddt.unpack
-    def test_tag_pattern(self, data):
-        self.assertIsNotNone(tag_pattern.match(data))
-        self.assertIsNotNone(tag_parser.parse_string(data, parse_all=True))
+    def test_colon_tag_pattern(self, data):
+        self.assertIsNotNone(colon_tag_pattern.match(data))
+        self.assertIsNotNone(colon_tag_parser.parse_string(data, parse_all=True))
 
-    data_tag_pattern__bad_cases = [
+    data_colon_tag_pattern__bad_cases = [
         ("",),
-        ("::",),
+        (":",),
         ("dummy_",),
         ("_dummy",),
-        ("dummy_::",),
-        ("_dummy::",),
-        ("dummy::dummy_",),
-        ("dummy::_dummy",),
+        ("dummy_:",),
+        ("_dummy:",),
+        ("dummy:dummy_",),
+        ("dummy:_dummy",),
     ]
 
-    @ddt.idata(data_tag_pattern__bad_cases)
+    @ddt.idata(data_colon_tag_pattern__bad_cases)
     @ddt.unpack
-    def test_tag_pattern__bad_cases(self, data):
-        self.assertIsNone(tag_pattern.match(data))
+    def test_colon_tag_pattern__bad_cases(self, data):
+        self.assertIsNone(colon_tag_pattern.match(data))
         with self.assertRaises(pp.ParseException):
-            tag_parser.parse_string(data, parse_all=True)
+            colon_tag_parser.parse_string(data, parse_all=True)
+
+    data_slash_tag_pattern = [
+        ("dummy",),
+        ("dummy/dummy",),
+        ("dummy/dummy/dummy",),
+        ("dummy_12345/dummy_12345/dummy_12345",),
+    ]
+
+    @ddt.idata(data_slash_tag_pattern)
+    @ddt.unpack
+    def test_slash_tag_pattern(self, data):
+        self.assertIsNotNone(slash_tag_pattern.match(data))
+        self.assertIsNotNone(slash_tag_parser.parse_string(data, parse_all=True))
+
+    data_slash_tag_pattern__bad_cases = [
+        ("",),
+        ("/",),
+        ("dummy_",),
+        ("_dummy",),
+        ("dummy_/",),
+        ("_dummy/",),
+        ("dummy/dummy_",),
+        ("dummy/_dummy",),
+    ]
+
+    @ddt.idata(data_slash_tag_pattern__bad_cases)
+    @ddt.unpack
+    def test_slash_tag_pattern__bad_cases(self, data):
+        self.assertIsNone(slash_tag_pattern.match(data))
+        with self.assertRaises(pp.ParseException):
+            slash_tag_parser.parse_string(data, parse_all=True)
 
     data_topic_pattern = [
         ("/dummy_sensor",),
